@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # django-codenerix
 #
@@ -18,28 +17,29 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from codenerix.djng.angular_model import NgModelFormMixin
-from codenerix.djng import NgFormValidationMixin, NgForm, NgModelForm
-
-from django.utils.translation import gettext as _
-from django.forms.widgets import Select, CheckboxInput
 from django.forms import NullBooleanField
+from django.forms.widgets import CheckboxInput, Select
+from django.utils.translation import gettext as _
 
+from codenerix.djng import NgForm, NgFormValidationMixin, NgModelForm
+from codenerix.djng.angular_model import NgModelFormMixin
 from codenerix.helpers import model_inspect
 from codenerix.widgets import (
-    StaticSelect,
-    DynamicSelect,
     DynamicInput,
-    MultiStaticSelect,
+    DynamicSelect,
     MultiDynamicSelect,
+    MultiStaticSelect,
+    StaticSelect,
 )
 
 
-class BaseForm(object):
+class BaseForm:
     def __init__(self, *args, **kwargs):
         self.__language = None
         self.attributes = {}
-        return super(BaseForm, self).__init__(*args, **kwargs)
+        self.__codenerix_uuid = None
+        self.__codenerix_request = None
+        return super().__init__(*args, **kwargs)
 
     def set_language(self, language):
         self.__language = language
@@ -73,7 +73,11 @@ class BaseForm(object):
                 if lt not in valores_validos:
                     r = False
                     break
-            if not r or color[0] != "#" or not (len(color) == 4 or len(color) == 7):
+            if (
+                not r
+                or color[0] != "#"
+                or not (len(color) == 4 or len(color) == 7)
+            ):
                 self._errors["color"] = [_("Invalid color")]
                 return color
             else:
@@ -87,7 +91,10 @@ class BaseForm(object):
             list_errors = self.list_errors
         else:
             # r = self.non_field_errors()
-            # list_errors = [element[5] for element in list(self.non_field_errors())[:-1]]
+            # list_errors = [
+            #   element[5]
+            #   for element in list(self.non_field_errors())[:-1]
+            # ]
             list_errors = []
             for element in list(self.non_field_errors())[:-1]:
                 if len(element) >= 5:
@@ -107,6 +114,24 @@ class BaseForm(object):
     def __groups__(self):
         return []
 
+    @property
+    def codenerix_uuid(self):
+        return self.__codenerix_uuid
+
+    @codenerix_uuid.setter
+    def codenerix_uuid(self, uuid):
+        self.__codenerix_uuid = uuid
+        return uuid
+
+    @property
+    def codenerix_request(self):
+        return self.__codenerix_request
+
+    @codenerix_request.setter
+    def codenerix_request(self, request):
+        self.__codenerix_request = request
+        return request
+
     def get_groups(self, gs=None, processed=[], initial=True):
         """
         <--------------------------------------- 12 columns ------------------------------------>
@@ -197,12 +222,13 @@ class BaseForm(object):
         =====
         - autofill: autofill system (CODENERIX)
         - extend: extended variables system (CODENERIX)
+            Example: {"attr1": ["subattr1", "subattr2"]} -> it will inject in the scope attributes "subattr1" and "subattr2" from "object.attr1" if object is available (GenUpdate)
         - widgets: widgets system (DJANGO)
-        """
+        """  # noqa: E501
 
         # Check if language is set
         if not self.__language:
-            raise IOError("ERROR: No language suplied!")
+            raise OSError("ERROR: No language suplied!")
 
         # Initialize the list
         if initial:
@@ -251,12 +277,16 @@ class BaseForm(object):
 
             if token["name"] in html_helper:
                 if "pre" in html_helper[token["name"]]:
-                    token["html_helper_pre"] = html_helper[token["name"]]["pre"]
+                    token["html_helper_pre"] = html_helper[token["name"]][
+                        "pre"
+                    ]
                 if "post" in html_helper[token["name"]]:
-                    token["html_helper_post"] = html_helper[token["name"]]["post"]
+                    token["html_helper_post"] = html_helper[token["name"]][
+                        "post"
+                    ]
 
             styles = g[1]
-            if type(styles) is tuple:
+            if isinstance(styles, tuple):
                 if len(styles) >= 1:
                     token["columns"] = g[1][0]
                 if len(styles) >= 2:
@@ -279,7 +309,7 @@ class BaseForm(object):
                 # Field
                 atr = {}
                 # Decide weather this is a Group or not
-                if type(f) == tuple:
+                if isinstance(f, tuple):
                     # Recursive
                     fields += self.get_groups([list(f)], processed, False)
                 else:
@@ -293,7 +323,7 @@ class BaseForm(object):
                             str,
                         ]
                     # Check if it is a list
-                    if type(f) == list:
+                    if isinstance(f, list):
                         # This is a field with attributes, get the name
                         field = f[0]
 
@@ -303,44 +333,53 @@ class BaseForm(object):
                             and "items" in html_helper[token["name"]]
                             and field in html_helper[token["name"]]["items"]
                         ):
-                            if "pre" in html_helper[token["name"]]["items"][field]:
-                                atr["html_helper_pre"] = html_helper[token["name"]][
-                                    "items"
-                                ][field]["pre"]
-                            if "post" in html_helper[token["name"]]["items"][field]:
-                                atr["html_helper_post"] = html_helper[token["name"]][
-                                    "items"
-                                ][field]["post"]
+                            if (
+                                "pre"
+                                in html_helper[token["name"]]["items"][field]
+                            ):
+                                atr["html_helper_pre"] = html_helper[
+                                    token["name"]
+                                ]["items"][field]["pre"]
+                            if (
+                                "post"
+                                in html_helper[token["name"]]["items"][field]
+                            ):
+                                atr["html_helper_post"] = html_helper[
+                                    token["name"]
+                                ]["items"][field]["post"]
 
                         # Process each attribute (if any)
                         dictionary = False
                         for idx, element in enumerate(f[1:]):
-                            if type(element) == dict:
+                            if isinstance(element, dict):
                                 dictionary = True
                                 for key in element.keys():
                                     if key in labels:
                                         atr[key] = element[key]
                                     else:
-                                        raise IOError(
-                                            "Unknown attribute '{0}' as field '{1}' in list of fields".format(
-                                                key, field
-                                            )
+                                        raise OSError(
+                                            f"Unknown attribute '{key}' as "
+                                            f"field '{field}' in list "
+                                            "of fields",
                                         )
                             else:
                                 if not dictionary:
                                     if element is not None:
                                         atr[attributes[idx][0]] = element
                                 else:
-                                    raise IOError(
-                                        "We already processed a dicionary element in this list of fields, you can not add anoother type of elements to it, you must keep going with dictionaries"
+                                    raise OSError(
+                                        "We already processed a dicionary "
+                                        "element in this list of fields, you "
+                                        "can not add anoother type of "
+                                        "elements to it, you must keep going "
+                                        "with dictionaries",
                                     )
                     elif type(f) in list_type:
                         field = f
                     else:
-                        raise IOError(
-                            "Uknown element type '{0}' inside group '{1}'".format(
-                                type(f), token["name"]
-                            )
+                        raise OSError(
+                            f"Uknown element type '{type(f)}' inside "
+                            f"group '{token['name']}'",
                         )
 
                     # Get the Django Field object
@@ -362,7 +401,6 @@ class BaseForm(object):
                             break
 
                     if foundbool:
-
                         # Get attributes (required and original attributes)
                         wrequired = found.field.widget.is_required
                         wattrs = found.field.widget.attrs
@@ -372,7 +410,10 @@ class BaseForm(object):
                         atr["input"] = found
                         atr["inputbool"] = foundbool
                         atr["focus"] = False
-                        atr["extend"] = self.get_extends(found.html_name, userextend)
+                        atr["extend"] = self.get_extends(
+                            found.html_name,
+                            userextend,
+                        )
 
                         # Set focus
                         if focus_must is None:
@@ -383,90 +424,123 @@ class BaseForm(object):
 
                         # Autocomplete
                         if "autofill" in dir(self.Meta):
-
-                            autofill = self.Meta.autofill.get(found.html_name, None)
+                            autofill = self.Meta.autofill.get(
+                                found.html_name,
+                                None,
+                            )
                             atr["autofill"] = autofill
 
                             if autofill:
-
                                 # Check format of the request
                                 autokind = autofill[0]
-                                if type(autokind) == str:
-
-                                    # Replace widget if the user didn't define any
+                                if isinstance(autokind, str):
+                                    # Replace widget if the user didn't
+                                    # define any
                                     if not userwidget:
-
                                         # Using new format
                                         if autokind == "select":
-
-                                            # If autofill is True for this field set the DynamicSelect widget
-                                            found.field.widget = DynamicSelect(wattrs)
+                                            # If autofill is True for this
+                                            # field set the DynamicSelect
+                                            # widget
+                                            found.field.widget = DynamicSelect(
+                                                wattrs,
+                                            )
 
                                         elif autokind == "multiselect":
-
-                                            # If autofill is True for this field set the DynamicSelect widget
-                                            found.field.widget = MultiDynamicSelect(
-                                                wattrs
+                                            # If autofill is True for this
+                                            # field set the DynamicSelect
+                                            # widget
+                                            found.field.widget = (
+                                                MultiDynamicSelect(wattrs)
                                             )
 
                                         elif autokind == "input":
-
-                                            # If autofill is True for this field set the DynamicSelect widget
-                                            found.field.widget = DynamicInput(wattrs)
+                                            # If autofill is True for this
+                                            # field set the DynamicSelect
+                                            # widget
+                                            found.field.widget = DynamicInput(
+                                                wattrs,
+                                            )
 
                                         else:
-
-                                            raise IOError(
-                                                "Autofill filled using new format but autokind is '{}' and I only know 'input' or 'select'".format(
-                                                    autokind
-                                                )
+                                            raise OSError(
+                                                "Autofill filled using new "
+                                                "format but autokind is "
+                                                f"'{autokind}' and I only "
+                                                "know 'input' or 'select'",
                                             )
 
                                     # Configure widget
                                     found.field.widget.is_required = wrequired
-                                    found.field.widget.form_name = self.form_name
-                                    found.field.widget.field_name = infield.html_name
-                                    found.field.widget.autofill_deepness = autofill[1]
-                                    found.field.widget.autofill_url = autofill[2]
+                                    found.field.widget.form_name = (
+                                        self.form_name
+                                    )
+                                    found.field.widget.field_name = (
+                                        infield.html_name
+                                    )
+                                    found.field.widget.autofill_deepness = (
+                                        autofill[1]
+                                    )
+                                    found.field.widget.autofill_url = autofill[
+                                        2
+                                    ]
                                     found.field.widget.autofill = autofill[3:]
 
                                 else:
+                                    # Get old information [COMPATIBILITY WITH
+                                    # OLD VERSION]
 
-                                    # Get old information [COMPATIBILITY WITH OLD VERSION]
-
-                                    # Replace widget if the user didn't define any
+                                    # Replace widget if the user didn't
+                                    # define any
                                     if not userwidget:
-
-                                        # If autofill is True for this field set the DynamicSelect widget
-                                        found.field.widget = DynamicSelect(wattrs)
+                                        # If autofill is True for this field
+                                        # set the DynamicSelect widget
+                                        found.field.widget = DynamicSelect(
+                                            wattrs,
+                                        )
 
                                     # Configure widget
                                     found.field.widget.is_required = wrequired
-                                    found.field.widget.form_name = self.form_name
-                                    found.field.widget.field_name = infield.html_name
-                                    found.field.widget.autofill_deepness = autofill[0]
-                                    found.field.widget.autofill_url = autofill[1]
+                                    found.field.widget.form_name = (
+                                        self.form_name
+                                    )
+                                    found.field.widget.field_name = (
+                                        infield.html_name
+                                    )
+                                    found.field.widget.autofill_deepness = (
+                                        autofill[0]
+                                    )
+                                    found.field.widget.autofill_url = autofill[
+                                        1
+                                    ]
                                     found.field.widget.autofill = autofill[2:]
                         else:
-
                             # Set we don't have autofill for this field
                             atr["autofill"] = None
 
-                        # Check if we have to replace the widget with a newer one
-                        if isinstance(found.field.widget, Select) and not isinstance(
-                            found.field.widget, DynamicSelect
+                        # Check if we have to replace the widget with a
+                        # newer one
+                        if isinstance(
+                            found.field.widget,
+                            Select,
+                        ) and not isinstance(
+                            found.field.widget,
+                            DynamicSelect,
                         ):
-                            # Replace widget if the user didn't define any and we haven't done yet
+                            # Replace widget if the user didn't define any and
+                            # we haven't done yet
                             if (
                                 (not userwidget)
                                 and (
                                     not isinstance(
-                                        found.field.widget, MultiStaticSelect
+                                        found.field.widget,
+                                        MultiStaticSelect,
                                     )
                                 )
                                 and (
                                     not isinstance(
-                                        found.field.widget, MultiDynamicSelect
+                                        found.field.widget,
+                                        MultiDynamicSelect,
                                     )
                                 )
                             ):
@@ -477,7 +551,7 @@ class BaseForm(object):
                             found.field.widget.field_name = infield.html_name
 
                         # Fill all attributes
-                        for (attribute, default) in attributes:
+                        for attribute, default in attributes:
                             if attribute not in atr.keys():
                                 atr[attribute] = default
                         # Fill label
@@ -487,7 +561,11 @@ class BaseForm(object):
                         flang = getattr(found.field, "set_language", None)
                         if flang:
                             flang(self.__language)
-                        flang = getattr(found.field.widget, "set_language", None)
+                        flang = getattr(
+                            found.field.widget,
+                            "set_language",
+                            None,
+                        )
                         if flang:
                             flang(self.__language)
                         # Attach the element
@@ -495,10 +573,9 @@ class BaseForm(object):
                         # Remember we have processed it
                         processed.append(found.__dict__[check_system])
                     else:
-                        raise IOError(
-                            "Unknown field '{0}' specified in group '{1}'".format(
-                                f, token["name"]
-                            )
+                        raise OSError(
+                            f"Unknown field '{f}' specified in "
+                            f"group '{token['name']}'",
                         )
 
             token["fields"] = fields
@@ -506,21 +583,24 @@ class BaseForm(object):
 
         # Add the rest of attributes we didn't use yet
         if initial:
-
             fields = []
             for infield in list_fields:
-
                 if infield.__dict__[check_system] not in processed:
-
                     # Check if the user specified a widget
                     if "widgets" in dir(self.Meta):
-                        userwidget = self.Meta.widgets.get(infield.html_name, None)
+                        userwidget = self.Meta.widgets.get(
+                            infield.html_name,
+                            None,
+                        )
                     else:
                         userwidget = None
 
                     # Check if the user specified a extend
                     if "extend" in dir(self.Meta):
-                        userextend = self.Meta.extend.get(infield.html_name, None)
+                        userextend = self.Meta.extend.get(
+                            infield.html_name,
+                            None,
+                        )
                     else:
                         userextend = None
 
@@ -536,7 +616,10 @@ class BaseForm(object):
                     atr["input"] = infield
                     atr["inputbool"] = True
                     atr["focus"] = False
-                    atr["extend"] = self.get_extends(infield.html_name, userextend)
+                    atr["extend"] = self.get_extends(
+                        infield.html_name,
+                        userextend,
+                    )
 
                     # Set focus
                     if focus_must is None:
@@ -547,96 +630,118 @@ class BaseForm(object):
 
                     # Autocomplete
                     if "autofill" in dir(self.Meta):
-
-                        autofill = self.Meta.autofill.get(infield.html_name, None)
+                        autofill = self.Meta.autofill.get(
+                            infield.html_name,
+                            None,
+                        )
                         atr["autofill"] = autofill
 
                         if autofill:
-
                             # Check format of the request
                             autokind = autofill[0]
 
-                            if type(autokind) == str:
+                            if isinstance(autokind, str):
                                 # Get old information
 
                                 # Replace widget if the user didn't define any
                                 if not userwidget:
-
                                     # Using new format
                                     if autokind == "select":
-                                        # If autofill is True for this field set the DynamicSelect widget
-                                        infield.field.widget = DynamicSelect(wattrs)
+                                        # If autofill is True for this field
+                                        # set the DynamicSelect widget
+                                        infield.field.widget = DynamicSelect(
+                                            wattrs,
+                                        )
                                     elif autokind == "multiselect":
-                                        # If autofill is True for this field set the DynamicSelect widget
-                                        infield.field.widget = MultiDynamicSelect(
-                                            wattrs
+                                        # If autofill is True for this field
+                                        # set the DynamicSelect widget
+                                        infield.field.widget = (
+                                            MultiDynamicSelect(wattrs)
                                         )
                                     elif autokind == "input":
-                                        # If autofill is True for this field set the DynamicSelect widget
-                                        infield.field.widget = DynamicInput(wattrs)
+                                        # If autofill is True for this field
+                                        # set the DynamicSelect widget
+                                        infield.field.widget = DynamicInput(
+                                            wattrs,
+                                        )
                                     else:
-                                        raise IOError(
-                                            "Autofill filled using new format but autokind is '{}' and I only know 'input' or 'select'".format(
-                                                autokind
-                                            )
+                                        raise OSError(
+                                            "Autofill filled using new "
+                                            "format but autokind is "
+                                            f"'{autokind}' and I only know "
+                                            "'input' or 'select'",
                                         )
 
                                 # Configure widget
                                 infield.field.widget.is_required = wrequired
                                 infield.field.widget.form_name = self.form_name
-                                infield.field.widget.field_name = infield.html_name
-                                infield.field.widget.autofill_deepness = autofill[1]
+                                infield.field.widget.field_name = (
+                                    infield.html_name
+                                )
+                                infield.field.widget.autofill_deepness = (
+                                    autofill[1]
+                                )
                                 infield.field.widget.autofill_url = autofill[2]
                                 infield.field.widget.autofill = autofill[3:]
                             else:
-                                # Get old information [COMPATIBILITY WITH OLD VERSION]
+                                # Get old information [COMPATIBILITY WITH
+                                # OLD VERSION]
 
                                 # Replace widget if the user didn't define any
                                 if not userwidget:
-
-                                    # If autofill is True for this field set the DynamicSelect widget
-                                    infield.field.widget = DynamicSelect(wattrs)
+                                    # If autofill is True for this field set
+                                    # the DynamicSelect widget
+                                    infield.field.widget = DynamicSelect(
+                                        wattrs,
+                                    )
 
                                 # Configure widget
                                 infield.field.widget.is_required = wrequired
                                 infield.field.widget.form_name = self.form_name
-                                infield.field.widget.field_name = infield.html_name
-                                infield.field.widget.autofill_deepness = autofill[0]
+                                infield.field.widget.field_name = (
+                                    infield.html_name
+                                )
+                                infield.field.widget.autofill_deepness = (
+                                    autofill[0]
+                                )
                                 infield.field.widget.autofill_url = autofill[1]
                                 infield.field.widget.autofill = autofill[2:]
                     else:
-
                         # Set we don't have autofill for this field
                         atr["autofill"] = None
 
                     # Check if we have to replace the widget with a newer one
-                    if isinstance(infield.field.widget, Select) and not isinstance(
-                        infield.field.widget, DynamicSelect
-                    ):
-
+                    if isinstance(
+                        infield.field.widget,
+                        Select,
+                    ) and not isinstance(infield.field.widget, DynamicSelect):
                         # Replace widget if the user didn't define any
                         if not userwidget:
-
                             if isinstance(infield.field, NullBooleanField):
                                 infield.field.widget = CheckboxInput(wattrs)
                             elif not isinstance(
-                                infield.field.widget, MultiStaticSelect
+                                infield.field.widget,
+                                MultiStaticSelect,
                             ) and not isinstance(
-                                infield.field.widget, MultiDynamicSelect
+                                infield.field.widget,
+                                MultiDynamicSelect,
                             ):
                                 infield.field.widget = StaticSelect(wattrs)
 
                         # Configure widget
-                        if hasattr(infield.field.widget, "choices") and hasattr(
-                            infield.field, "choices"
-                        ):
-                            infield.field.widget.choices = infield.field.choices
+                        if hasattr(
+                            infield.field.widget,
+                            "choices",
+                        ) and hasattr(infield.field, "choices"):
+                            infield.field.widget.choices = (
+                                infield.field.choices
+                            )
                         infield.field.widget.is_required = wrequired
                         infield.field.widget.form_name = self.form_name
                         infield.field.widget.field_name = infield.html_name
 
                     # Fill all attributes
-                    for (attribute, default) in attributes:
+                    for attribute, default in attributes:
                         if attribute not in atr.keys():
                             atr[attribute] = default
                     # Fill label
@@ -676,11 +781,25 @@ class BaseForm(object):
                 }
             }
         }
-        """
+        """  # noqa: E501
         return {}
 
 
-class GenModelForm(BaseForm, NgModelFormMixin, NgFormValidationMixin, NgModelForm):
+class GenModelForm(
+    BaseForm,
+    NgModelFormMixin,
+    NgFormValidationMixin,
+    NgModelForm,
+):
+    def save(self, *args, **kwargs):
+        # Prepare the instance
+        self.instance.codenerix_uuid = self.codenerix_uuid
+        self.instance.codenerix_request = self.codenerix_request
+        # Save the object
+        obj = super().save(*args, **kwargs)
+        # Return the object
+        return obj
+
     pass
 
 
