@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # django-codenerix
 #
@@ -18,35 +17,42 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# System
-import os
-from datetime import datetime
-import random
-from dateutil.tz import tzutc
-import zipfile
-import io
-import json
-from unidecode import unidecode
-from uuid import UUID
-import time
 import decimal
 import importlib
+import io
+import json
 
+try:
+    import pyotp
+except ImportError:
+    pyotp = None  # type: ignore
+
+# System
+import os
+import random
+import time
+import zipfile
+from datetime import datetime
+from uuid import UUID
+
+from dateutil.tz import tzutc
+from django.conf import settings
+from django.core.cache import cache
+from django.core.serializers.json import DjangoJSONEncoder
 
 # Django
 from django.db.models import Q
-from django.utils.encoding import smart_str
-from django.utils.translation import gettext_lazy as _
+from django.http import HttpResponseRedirect
+from django.shortcuts import render
 from django.template import TemplateDoesNotExist
 from django.template.loader import get_template as django_get_template
-from django.shortcuts import render
-from django.conf import settings
-from django.views.generic.base import View
-from django.core.cache import cache
-from django.utils import dateparse
-from django.http import HttpResponseRedirect
-from django.utils.http import urlsafe_base64_encode
 from django.urls import reverse_lazy
+from django.utils import dateparse
+from django.utils.encoding import smart_str
+from django.utils.http import urlsafe_base64_encode
+from django.utils.translation import gettext_lazy as _
+from django.views.generic.base import View
+from unidecode import unidecode
 
 
 def epochdate(timestamp):
@@ -59,8 +65,8 @@ def epochdate(timestamp):
     """
 
     dt = datetime.fromtimestamp(float(timestamp)).timetuple()
-    fecha = "{0:d}-{1:02d}-{2:02d}".format(dt.tm_year, dt.tm_mon, dt.tm_mday)
-    hora = "{0:02d}:{1:02d}:{2:02d}".format(dt.tm_hour, dt.tm_min, dt.tm_sec)
+    fecha = "{:d}-{:02d}-{:02d}".format(dt.tm_year, dt.tm_mon, dt.tm_mday)
+    hora = "{:02d}:{:02d}:{:02d}".format(dt.tm_hour, dt.tm_min, dt.tm_sec)
     return (fecha, hora)
 
 
@@ -89,7 +95,10 @@ def date2string(dtime, formt, default):
 def daterange_filter(value, variable):
     start = dateparse.parse_datetime(value["startDate"])
     end = dateparse.parse_datetime(value["endDate"])
-    result = {"{0}__gte".format(variable): start, "{0}__lte".format(variable): end}
+    result = {
+        "{}__gte".format(variable): start,
+        "{}__lte".format(variable): end,
+    }
     return result
 
 
@@ -174,10 +183,10 @@ def nameunify(name, url=False):
     return result
 
 
-def get_profile(user):
+def get_profile(user, admingroup="Admins"):
     # Check if it has admin rights admin
     try:
-        is_admin = bool(user.is_superuser or user.groups.get(name="Admins"))
+        is_admin = bool(user.is_superuser or user.groups.get(name=admingroup))
     except Exception:
         is_admin = False
 
@@ -198,15 +207,21 @@ def get_profiled_paths(path, user, lang, extension):
         profile = get_profile(user)
 
         # Define the base_path to use
-        paths.append("{0}.{1}".format(user.username, lang))
+        paths.append("{}.{}".format(user.username, lang))
         paths.append(user.username)
         if profile:
-            paths.append("{0}.{1}".format(profile, lang))
+            paths.append("{}.{}".format(profile, lang))
             paths.append(profile)
         if profile != "admin":
-            paths.append("user.{0}".format(lang))
+            paths.append("user.{}".format(lang))
             paths.append("user")
 
+        # Add group paths
+        if user.groups.count():
+            for group in user.groups.all():
+                paths.append("{}.{}".format(group.name.lower(), lang))
+                paths.append(group.name.lower())
+
     # Add an empty path
     paths.append(lang)
     paths.append("")
@@ -224,7 +239,12 @@ def get_profiled_paths(path, user, lang, extension):
 
 def get_template(template, user, lang, extension="html", raise_error=True):
     # Get profiled paths
-    (templates, templatepath) = get_profiled_paths(template, user, lang, extension)
+    (templates, templatepath) = get_profiled_paths(
+        template,
+        user,
+        lang,
+        extension,
+    )
 
     # Check templates
     test = []
@@ -248,8 +268,10 @@ def get_template(template, user, lang, extension="html", raise_error=True):
         return found
     else:
         if raise_error:
-            raise IOError(
-                "I couldn't find a valid template, I have tried: {}".format(test)
+            raise OSError(
+                "I couldn't find a valid template, I have tried: {}".format(
+                    test,
+                ),
             )
         else:
             return test
@@ -267,6 +289,15 @@ def get_static(desired, user, lang, default, extension="html", relative=False):
         else:
             addon = ""
         target = "%s%s.%s" % (basepath, addon, extension)
+
+        # DEBUG
+        # debug_path = os.path.join(settings.STATIC_ROOT, target)
+        # exists = os.path.exists(debug_path)
+        # if exists:
+        #     print(f"{debug_path} ---> {exists}")
+        # else:
+        #     print(f".    {debug_path} ---> {exists}")
+
         if (
             hasattr(settings, "STATIC_ROOT")
             and settings.STATIC_ROOT
@@ -312,7 +343,12 @@ def model_inspect(obj):
         model = obj.__class__
 
     namesp = str(model)
-    namesp = namesp.replace("<class ", "").replace(">", "").replace("'", "").split(".")
+    namesp = (
+        namesp.replace("<class ", "")
+        .replace(">", "")
+        .replace("'", "")
+        .split(".")
+    )
 
     # Remember information
     info["appname"] = namesp[-3]
@@ -325,8 +361,8 @@ def model_inspect(obj):
 
 def upload_path(instance, filename):
     """
-    This method is created to return the path to upload files. This path must be
-    different from any other to avoid problems.
+    This method is created to return the path to upload files. This path
+    must be different from any other to avoid problems.
     """
     path_separator = "/"
     date_separator = "-"
@@ -346,11 +382,11 @@ def upload_path(instance, filename):
     file_ext = split_filename[-1]
 
     new_filename = empty_string.join(
-        [filename, str(random.random()).split(ext_separator)[1]]
+        [filename, str(random.random()).split(ext_separator)[1]],
     )
     new_filename = ext_separator.join([new_filename, file_ext])
     string_path = path_separator.join(
-        [model_name, curr_year, curr_month, curr_day, new_filename]
+        [model_name, curr_year, curr_month, curr_day, new_filename],
     )
     # the path is built using the current date and the modelname
     return string_path
@@ -391,15 +427,14 @@ def clean_memcache_item(key, item):
         cache.set(key, result)
 
 
-class CodenerixEncoder(object):
-
+class CodenerixEncoder:
     codenerix_numeric_dic = {
         # Basic dicts
         "num": "0123456789",
         "alpha": "ABCDEFGHIJKLMNOPQRSTUVWXYZ",
         "alphanc": "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ",
         "alphanum": "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ",
-        "alphanumnc": "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ",
+        "alphanumnc": "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ",  # noqa: E501
         # Original dicts
         "hex36": "ENWR6MV71JOQHADUGFCYZ25X3B4L0KPTSI98",
         "hex16": "54BEF80D1C96A732",
@@ -410,7 +445,6 @@ class CodenerixEncoder(object):
         return self.codenerix_numeric_dic.keys()
 
     def numeric_encode(self, number, dic="hex36", length=None, cfill=None):
-
         # Get predefined dictionary
         if dic in self.codenerix_numeric_dic:
             dic = self.codenerix_numeric_dic[dic]
@@ -421,7 +455,7 @@ class CodenerixEncoder(object):
             if c not in nr:
                 nr += c
             else:
-                raise IOError(_("ERROR: dic has repeated elements"))
+                raise OSError(_("ERROR: dic has repeated elements"))
 
         # If no cfill
         if cfill is None:
@@ -453,7 +487,6 @@ class CodenerixEncoder(object):
         return string[::-1]
 
     def numeric_decode(self, string, dic="hex36"):
-
         # Get predefined dictionary
         if dic in self.codenerix_numeric_dic:
             dic = self.codenerix_numeric_dic[dic]
@@ -462,7 +495,6 @@ class CodenerixEncoder(object):
         first = True
         number = 0
         for c in string:
-
             # Not the first loop
             if not first:
                 number *= len(dic)
@@ -476,7 +508,7 @@ class CodenerixEncoder(object):
         return number
 
 
-class InMemoryZip(object):
+class InMemoryZip:
     """
     # Compress
     imz = InMemoryZip()
@@ -512,7 +544,12 @@ class InMemoryZip(object):
         self.in_memory_zip.seek(-1, io.SEEK_END)
 
         # Get a handle to the in-memory zip in append mode
-        zf = zipfile.ZipFile(self.in_memory_zip, "a", zipfile.ZIP_DEFLATED, False)
+        zf = zipfile.ZipFile(
+            self.in_memory_zip,
+            "a",
+            zipfile.ZIP_DEFLATED,
+            False,
+        )
 
         # Write the file to the in-memory zip
         zf.writestr(filename_in_zip, file_contents)
@@ -532,7 +569,12 @@ class InMemoryZip(object):
 
     def get(self, filename):
         self.in_memory_zip.seek(0)
-        zf = zipfile.ZipFile(self.in_memory_zip, "r", zipfile.ZIP_DEFLATED, False)
+        zf = zipfile.ZipFile(
+            self.in_memory_zip,
+            "r",
+            zipfile.ZIP_DEFLATED,
+            False,
+        )
         fp = zf.open(filename)
         data = fp.read()
         # Close the ZipFile
@@ -588,7 +630,7 @@ def trace_json_error(struct, path=[]):
             idx += 1
     else:
         try:
-            json.dumps(struct)
+            json.dumps(struct, cls=DjangoJSONEncoder)
         except Exception:
             found = path
 
@@ -632,27 +674,32 @@ def form_answer(status, answer):
         answer["__str__"] = "OK"
 
     # Encode answer
-    answer_encoded = urlsafe_base64_encode(str.encode(json.dumps(answer))).decode()
+    answer_encoded = urlsafe_base64_encode(
+        str.encode(json.dumps(answer, cls=DjangoJSONEncoder)),
+    ).decode()
 
     # Build success URL
     success_url = reverse_lazy(
-        "CDNX_status", kwargs={"status": "accept", "answer": answer_encoded}
+        "CDNX_status",
+        kwargs={"status": "accept", "answer": answer_encoded},
     )
 
     # Return response
     return HttpResponseRedirect(success_url)
 
 
-def JSONEncoder_newdefault(kind=["uuid", "datetime", "time", "decimal"]):
+def JSONEncoder_newdefault(  # noqa: N802
+    kind=["uuid", "datetime", "time", "decimal"],
+):
     """
     JSON Encoder newdfeault is a wrapper capable of encoding several kinds
     Usage:
         from codenerix.helpers import JSONEncoder_newdefault
         JSONEncoder_newdefault()
     """
-    JSONEncoder_olddefault = json.JSONEncoder.default
+    JSONEncoder_olddefault = json.JSONEncoder.default  # noqa: N806
 
-    def JSONEncoder_wrapped(self, o):
+    def JSONEncoder_wrapped(self, o):  # noqa: N802
         """
         json.JSONEncoder.default = JSONEncoder_newdefault
         """
@@ -680,7 +727,59 @@ def context_processors_update(context, request):
         for context_processor in template["OPTIONS"]["context_processors"]:
             path = context_processor.split(".")
             name = path.pop(-1)
-            processor = getattr(importlib.import_module(".".join(path)), name, None)
+            processor = getattr(
+                importlib.import_module(".".join(path)),
+                name,
+                None,
+            )
             if processor:
                 context.update(processor(request))
     return context
+
+
+class SearchFAutoFilter:
+    """
+    Class for helping buildin filters
+    """
+
+    @classmethod
+    def factory(cls, field, label):
+        return (
+            label,
+            cls.get_lambda(field),
+            cls.get_options(),
+        )
+
+    @classmethod
+    def get_options(cls):
+        return [
+            (f"{operation}{value}", label)
+            for (label, operation, value) in cls.options
+        ]
+
+    @classmethod
+    def get_lambda(cls, counterfield):
+        def filtercount(filtering):
+            filt = {counterfield: 0}
+            for label, operation, value in cls.options:
+                key = f"{operation}{value}"
+                if filtering == key:
+                    if operation is None:
+                        filt = {f"{counterfield}": value}
+                    else:
+                        filt = {f"{counterfield}__{operation}": value}
+                    break
+            print(filt)
+            return Q(**filt)
+
+        return filtercount
+
+
+def otpauth(issuer, label, secret):
+    if secret and pyotp:
+        return pyotp.totp.TOTP(secret).provisioning_uri(
+            name=label,
+            issuer_name=issuer,
+        )
+    else:
+        return None
