@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # django-codenerix
 #
@@ -21,82 +20,98 @@
 import re
 from threading import local
 
-from django.shortcuts import redirect
 from django.conf import settings
+from django.shortcuts import redirect
 
 
-class SecureRequiredMiddleware(object):
+class SecureRequiredMiddleware:
     def __init__(self, get_response=None):
         self.get_response = get_response
-        self.paths = getattr(settings, 'HTTPS_PATHS', getattr(settings, 'SECURE_REQUIRED_PATHS', ('/', )))
-        self.enabled = self.paths and getattr(settings, 'HTTPS_SUPPORT', True)
-    
-    def process_request(self, request):
-        
-        if self.enabled and not request.is_secure():
+        self.paths = getattr(
+            settings,
+            "HTTPS_PATHS",
+            getattr(settings, "SECURE_REQUIRED_PATHS", ("/",)),
+        )
+        self.enabled = self.paths and getattr(settings, "HTTPS_SUPPORT", True)
 
+    def process_request(self, request):
+        if self.enabled and not request.is_secure():
             # Check for negative matching, URLs we don't want to be secure
             for path in self.paths:
                 full_path = request.get_full_path()
-                if path[0] == '-' and (full_path.startswith(path[1:]) or re.compile(path[1:]).match(full_path)):
+                if path[0] == "-" and (
+                    full_path.startswith(path[1:])
+                    or re.compile(path[1:]).match(full_path)
+                ):
                     return None
-                
+
             # Check for positive matching, URLs we want to be secure
             for path in self.paths:
                 full_path = request.get_full_path()
-                if full_path.startswith(path) or re.compile(path).match(full_path):
-                    request_url = request.build_absolute_uri(request.get_full_path())
-                    secure_url = request_url.replace('http://', 'https://')
+                if full_path.startswith(path) or re.compile(path).match(
+                    full_path,
+                ):
+                    request_url = request.build_absolute_uri(
+                        request.get_full_path(),
+                    )
+                    secure_url = request_url.replace("http://", "https://")
                     return redirect(secure_url, permanent=True)
 
         # Any other lateral case
         return None
-    
+
     def __call__(self, request):
-        # Code to be executed for each request before the view (and later middleware) are called.
+        # Code to be executed for each request before the view (and later
+        # middleware) are called.
         response = self.process_request(request)
-        
+
         # Get response
         if response is None:
             response = self.get_response(request)
-        
-        # Code to be executed for each request/response after the view is called
+
+        # Code to be executed for each request/response after the
+        # view is called
         # ... pass ...
-        
+
         # Return response
         return response
 
 
-class CurrentUserMiddleware(object):
-    '''
+class CurrentUserMiddleware:
+    """
     Let the system to have the username everywhere
-    '''
+    """
+
     def __init__(self, get_response=None):
         self.get_response = get_response
-    
+
     def process_request(self, request):
         _user.value = request.user
-    
+
     def __call__(self, request):
-        # Code to be executed for each request before the view (and later middleware) are called.
+        # Code to be executed for each request before the view (and
+        # later middleware) are called.
         self.process_request(request)
-        
+
         # Get response
         response = self.get_response(request)
-        
-        # Code to be executed for each request/response after the view is called
+
+        # Code to be executed for each request/response after the
+        # view is called
         # ... pass ...
-        
+
         # Return response
         return response
-    
+
+
 def get_current_user():
-    '''
+    """
     Thought this function you can get the user loged in everywhere
-    '''
-    if 'value' in dir(_user):
+    """
+    if "value" in dir(_user):
         return _user.value
     else:
         return None
-_user = local()
 
+
+_user = local()
